@@ -97,7 +97,7 @@ class EWAHFBOperator(EWAHBaseOperator):
 
         super().__init__(*args, **kwargs)
 
-        credentials = BaseHook.get_connection(self.source_conn_id)
+        credentials = self.source_conn
         extra = credentials.extra_dejson
 
         # Note: app_secret is not always required!
@@ -131,11 +131,11 @@ class EWAHFBOperator(EWAHBaseOperator):
             if self.reload_data_from:
                 self.data_from = self.reload_data_from
 
+        self.data_from = self.data_from or context['execution_date']
+        self.data_until = self.data_until or context['next_execution_date']
         self.data_from = airflow_datetime_adjustments(self.data_from)
         self.data_until = airflow_datetime_adjustments(self.data_until)
 
-        self.data_from = self.data_from or context['execution_date']
-        self.data_until = self.data_until or context['next_execution_date']
 
         time_range = {
             'since': self.data_from.strftime('%Y-%m-%d'),
